@@ -5,7 +5,6 @@ A module implementing a network-connection interface.
 # built-in
 from abc import ABC as _ABC
 import asyncio as _asyncio
-from contextlib import suppress
 from typing import Awaitable as _Awaitable
 from typing import List as _List
 from typing import Optional as _Optional
@@ -13,6 +12,7 @@ from typing import TypeVar as _TypeVar
 from typing import Union as _Union
 
 # third-party
+from vcorelib.asyncio import log_exceptions as _log_exceptions
 from vcorelib.logging import LoggerMixin as _LoggerMixin
 from vcorelib.logging import LoggerType as _LoggerType
 
@@ -72,11 +72,15 @@ class Connection(_LoggerMixin, _ABC):
         """Determine if this connection is disabled."""
         return not self._enabled
 
+    def disable_extra(self) -> None:
+        """Additional tasks to perform when disabling."""
+
     def disable(self, reason: str) -> None:
         """Disable this connection."""
 
         if self._enabled:
             self.logger.info("Disabling connection: '%s'.", reason)
+            self.disable_extra()
             self._enabled = False
 
             # Cancel tasks.
@@ -84,7 +88,12 @@ class Connection(_LoggerMixin, _ABC):
                 if not task.done():
                     task.cancel()
 
-    async def process(self) -> None:
+    async def _wait_sig(self, stop_sig: _asyncio.Event) -> None:
+        """Disable the connection if a stop signal gets set."""
+        await stop_sig.wait()
+        self.disable("stop signal")
+
+    async def process(self, stop_sig: _asyncio.Event = None) -> None:
         """
         Process tasks for this connection while the connection is active.
         """
@@ -94,12 +103,15 @@ class Connection(_LoggerMixin, _ABC):
             _asyncio.create_task(self._process_write_text()),
             _asyncio.create_task(self._process_write_binary()),
         ]
+
+        # Allow a stop signal to also disable the connection.
+        if stop_sig is not None:
+            self._tasks.append(_asyncio.create_task(self._wait_sig(stop_sig)))
+
         await _asyncio.wait(self._tasks, return_when=_asyncio.ALL_COMPLETED)
 
-        # Ensure that cancelled tasks have their exceptions retrieved.
-        with suppress(_asyncio.CancelledError):
-            for task in self._tasks:
-                task.exception()
+        # Ensure that tasks have their exceptions retrieved.
+        _log_exceptions(self._tasks, self.logger)
 
         await self.close()
 
